@@ -68,6 +68,48 @@ def mixup(image, label, alpha=0.4):
     return image, label
 
 
+def get_box(mix_weight, height, width):
+    cut_rate = tf.math.sqrt(1.0 - mix_weight) / 2
+    cut_h, cut_w = tf.cast(cut_rate * float(height), tf.int32), tf.cast(cut_rate * float(width), tf.int32)
+    center_y = tf.random.uniform((1,), minval=cut_h, maxval=height - cut_h, dtype=tf.int32)[0]
+    center_x = tf.random.uniform((1,), minval=cut_w, maxval=width - cut_w, dtype=tf.int32)[0]
+    return center_y - cut_h, center_x - cut_w, cut_h, cut_w
+
+
+def cutmix(images, labels, alpha=0.5, min_mix_weight=0.01):
+    """
+    Copied and modified from https://keras.io/examples/vision/cutmix/
+
+    Example:
+    >>> from keras_cv_attention_models.imagenet import data
+    >>> import tensorflow_datasets as tfds
+    >>> dataset = tfds.load('cifar10', split='train').batch(16)
+    >>> dd = dataset.as_numpy_iterator().next()
+    >>> images, labels = dd['image'], tf.one_hot(dd['label'], depth=10)
+    >>> aa, bb = data.cutmix(images, labels)
+    >>> print(bb.numpy()[bb.numpy() != 0])
+    >>> plt.imshow(np.hstack(aa))
+    """
+    # Get a sample from the Beta distribution
+    batch_size = tf.shape(images)[0]
+    _, hh, ww, _ = images.shape
+    mix_weight = sample_beta_distribution(1, alpha, alpha)[0]  # same value in batch
+    if mix_weight < min_mix_weight or 1 - mix_weight < min_mix_weight:
+        # For input_shape=224, min_mix_weight=0.01, min_height = 224 * 0.1 = 22.4
+        return images, labels
+
+    offset_height, offset_width, target_height, target_width = get_box(mix_weight, hh, ww)
+    crops = tf.image.crop_to_bounding_box(images, offset_height, offset_width, target_height, target_width)
+    pad_crops = tf.image.pad_to_bounding_box(crops, offset_height, offset_width, hh, ww)
+
+    shuffle_index = tf.random.shuffle(tf.range(batch_size))
+    images = images - pad_crops + tf.gather(pad_crops, shuffle_index)
+    labels = tf.cast(labels, "float32")
+    label_mix_weight = tf.cast(tf.expand_dims(mix_weight, -1), "float32")
+    labels = labels * label_mix_weight + tf.gather(labels, shuffle_index) * (1 - label_mix_weight)
+    return images, labels
+
+
 def init_dataset(
     data_name="imagenet2012",
     input_shape=(224, 224),
@@ -76,6 +118,7 @@ def init_dataset(
     info_only=False,
     magnitude=0,
     mixup_alpha=0,
+    cutmix_alpha=0,
     keep_shape=False,
 ):
     dataset, info = tfds.load(data_name, with_info=True)
@@ -102,6 +145,9 @@ def init_dataset(
     if mixup_alpha > 0 and mixup_alpha <= 1:
         print(">>>> mixup_alpha provided:", mixup_alpha)
         train_dataset = train_dataset.map(lambda xx, yy: mixup(rescaling(xx), as_one_hot(yy), alpha=mixup_alpha))
+    elif cutmix_alpha > 0 and cutmix_alpha <= 1:
+        print(">>>> cutmix_alpha provided:", cutmix_alpha)
+        train_dataset = train_dataset.map(lambda xx, yy: cutmix(rescaling(xx), as_one_hot(yy), alpha=cutmix_alpha))
     else:
         train_dataset = train_dataset.map(lambda xx, yy: (rescaling(xx), as_one_hot(yy)))
     return train_dataset, test_dataset, total_images, num_classes, steps_per_epoch
