@@ -189,16 +189,29 @@ def outlook_attention_simple(inputs, embed_dim, num_head=6, kernel_size=3, attn_
 
 @tf.keras.utils.register_keras_serializable(package="volo")
 class BiasLayer(keras.layers.Layer):
-    def __init__(self, **kwargs):
+    def __init__(self, axis=-1, **kwargs):
         super(BiasLayer, self).__init__(**kwargs)
+        self.axis = axis
 
     def build(self, input_shape):
-        self.bb = self.add_weight(name="bias", shape=(input_shape[-1]), initializer="zeros", trainable=True)
+        if self.axis == -1 or self.axis == len(input_shape) - 1:
+            bb_shape = (input_shape[-1],)
+        else:
+            bb_shape = [1] * len(input_shape)
+            axis = self.axis if isinstance(self.axis, (list, tuple)) else [self.axis]
+            for ii in axis:
+                bb_shape[ii] = input_shape[ii]
+        self.bb = self.add_weight(name="bias", shape=bb_shape, initializer="zeros", trainable=True)
         super(BiasLayer, self).build(input_shape)
 
     def call(self, inputs, **kwargs):
         return inputs + self.bb
 
+    def get_config(self):
+        config = super(BiasLayer, self).get_config()
+        config.update({"axis": self.axis})
+        return config
+
 
 def attention_mlp_block(inputs, embed_dim, num_head=1, mlp_ratio=3, attention_type=None, drop_rate=0, mlp_activation="gelu", dropout=0, name=""):
     # print(f">>>> {drop_rate = }")
@@ -211,15 +224,15 @@ def attention_mlp_block(inputs, embed_dim, num_head=1, mlp_ratio=3, attention_ty
         nn_1 = outlook_attention_simple(nn_1, embed_dim, num_head=num_head, name=name + "attn_")
     elif attention_type == "class":
         # nn_1 = class_attention(nn_1, embed_dim, num_head=num_head, name=name + "attn_")
-        nn_1 = keras.layers.MultiHeadAttention(num_heads=num_head, key_dim=embed_dim // num_head, output_shape=embed_dim, use_bias=False, name=name + "attn_mhsa")(
-            nn_1[:, :1, :], nn_1
-        )
+        nn_1 = keras.layers.MultiHeadAttention(
+            num_heads=num_head, key_dim=embed_dim // num_head, output_shape=embed_dim, use_bias=False, name=name + "attn_mhsa"
+        )(nn_1[:, :1, :], nn_1)
         nn_1 = BiasLayer(name=name + "attn_bias")(nn_1)  # bias for output dense
     elif attention_type == "mhsa":
         # nn_1 = multi_head_self_attention(nn_1, embed_dim, num_head=num_head, name=name + "attn_")
-        nn_1 = keras.layers.MultiHeadAttention(num_heads=num_head, key_dim=embed_dim // num_head, output_shape=embed_dim, use_bias=False, name=name + "attn_mhsa")(
-            nn_1, nn_1
-        )
+        nn_1 = keras.layers.MultiHeadAttention(
+            num_heads=num_head, key_dim=embed_dim // num_head, output_shape=embed_dim, use_bias=False, name=name + "attn_mhsa"
+        )(nn_1, nn_1)
         nn_1 = BiasLayer(name=name + "attn_bias")(nn_1)  # bias for output dense
 
     if drop_rate > 0:
